@@ -1,3 +1,4 @@
+import sys
 import threading
 import faulthandler
 
@@ -8,9 +9,11 @@ from dearpygui import dearpygui as dpg
 from time import time
 from typing import Callable
 from screeninfo import get_monitors
-import sys
+from tempfile import NamedTemporaryFile
+
+if not sys.stderr:
+    sys.stderr = NamedTemporaryFile(delete=False)
 
-sys.stderr = open('err', 'w')
 faulthandler.enable()
 
 
@@ -124,8 +127,8 @@ class Popup:
         elif self.anchor_point == self.ON_SCREEN:
             x, y = self.ahk.get_mouse_position(coord_mode='Screen')
             monitor = self._get_bounding_monitor(x, y)
-            x = monitor.width / 2 - viewport_width / 2
-            y = monitor.height / 2 - viewport_height / 2
+            x = monitor.x + monitor.width / 2 - viewport_width / 2
+            y = monitor.y + monitor.height / 2 - viewport_height / 2
 
         dpg.set_viewport_pos((x, y))
 
@@ -218,6 +221,18 @@ class Popup:
         self.ahk.stop_hotkeys()
         dpg.destroy_context()
 
+    def add_text(self, label: str, **kwargs):
+        '''
+        Adds a text element to the popup window
+
+        :param label: The text label
+        :param kwargs: Additional Dear PyGUI arguments to pass to the text
+        :return: The text ID
+        '''
+        parent = kwargs.pop('parent', None) or dpg.top_container_stack() or self.root
+        text = dpg.add_text(label, parent=parent, **kwargs)
+        return text
+
     def add_button(self, label: str, callback: Callable, close=True, keybind: str = None, **kwargs):
         '''
         Adds a button to the popup window
@@ -345,6 +360,15 @@ class Popup:
         with dpg.handler_registry():
             handler(key=key, callback=self._keybind_callback(modifiers, callback))
 
+    def call_later(self, callback: Callable, frames=1):
+        '''
+        Schedules a callback to run after a certain number of frames
+
+        :param callback: The function to call
+        :param frames: The number of frames to wait before calling the function
+        '''
+        dpg.set_frame_callback(dpg.get_frame_count() + frames, callback=callback)
+
     # Callbacks and callback wrappers
     def no_op(self):
         '''Does nothing'''
